NAME = "bluer_ugv"

ICON = "🐬"

DESCRIPTION = f"{ICON} AI x UGV."

VERSION = "7.212.1"

REPO_NAME = "bluer-ugv"

MARQUEE = (
    "https://github.com/kamangir/assets2/raw/main/arzhang/VID-20250905-WA0014_1.gif"
)


ALIAS = "@ugv"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
